#Generate a series of R scripts to run EEMD in parallel
#along with a shell script to execute them
#using the BSUB parallel manager

trials <- 1000 #Number of EEMD trials
trials.per.script <- 2 #Trials per core
dir.create("parallel_r_scripts")

for(t in seq_len(trials/trials.per.script)) {

    script.code <- paste(
        "library(hht)",
        "dt <- 0.01",
        "noise.amp <- 0.1",
        "tt <- seq_len(10000)*dt",
        "sig <- cos(2*pi*tt+0.5*sin(4*pi*tt))+sin(pi*tt/10)+rnorm(length(tt),0,noise.amp)",
        paste("trials <- ", trials.per.script, sep = ""),
        "nimf <- 10",
        paste("trials.dir <- \"/netscr/haksaeng/hht/batch_", sprintf("%04d", t), "\"", sep = ""),
        "EEMD(sig, tt, noise.amp, trials, nimf, trials.dir = trials.dir)",
        sep = "\n")
       
    sh.script <- paste(
        "bsub -q hour -o ",
        "parallel_r_scripts/script_",
        sprintf("%04d", t),
        ".R.log ",
        "\"R CMD BATCH --vanilla ",
        "parallel_r_scripts/script_", sprintf("%04d", t), ".R\"\n",
        sep = "") 
    cat(script.code, file = paste("parallel_r_scripts/script_", sprintf("%04d", t), ".R", sep = "")) 
    cat(sh.script, file = "run_parallel_EEMD.sh", append = TRUE)
}

#Now compile the resulting directories into one directory,
#load them and make sure everything looks good

in.dirs <- list.files(include.dirs = TRUE, pattern = "batch_\\d{4}")
out.dir <- "stokes_eemd"
CombineTrials(in.dirs, out.dir)

#Load the trial files, make sure they look good

eemd.result <- EEMDCompile(out.dir, 1000, 10)
PlotIMFs(eemd.result)

